/// <reference types="node" />
import * as fs from 'fs';
import gm from 'gm';
import { CkValue, CkType } from '@ckstack/ck-lib';
declare class CkFileUtils {
    /**
     * log object 를 초기화 한다.
     * @deprecated 2022.11.24 일 부터 더 이상 사용 하지 않는다.
     */
    static init(): void;
    private static __crop;
    private static __resize;
    /**
     * async 로 파일을 read 하여 버프를 리턴 한다.
     * 정상으로 처리 되면 Promise<Buffer> 를 리턴 하고, 읽기 실패하면 error 를 throw 하거나 null 을 리턴 한다.
     * @param reqIpAndLhdAndHttpInfo 로그키
     * @param filePath 파일의 절대 경로
     * @param lang 언어 코드. 에러 로그 처리시 사용 됨. 없어도 무방.
     * @throws CkError
     */
    static readAsyncFileToBuffer(reqIpAndLhdAndHttpInfo: string, filePath: string, lang?: CkValue.SUPPORT_LANG): Promise<Buffer> | null;
    /**
     * Buffer 에 저장된 파일 데이터를 물리 파일로 저장 한다. 파일 저장을 실패 하면 error 를 throw 한다.
     * @param reqIpAndLhdAndHttpInfo
     * @param srcBuffer
     * @param destFilePath
     * @param opt
     * @param lang
     * @throws CkError
     */
    static writeAsyncBufferToFile(reqIpAndLhdAndHttpInfo: string, srcBuffer: Buffer, destFilePath: string, opt?: fs.WriteFileOptions, lang?: CkValue.SUPPORT_LANG): void;
    static mkdirs(dir: string, reqIpAndLhdAndHttpInfo?: string): void;
    static removeFileOrDirectory(filePath: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): void;
    static copy(src: string, dest: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): Promise<string>;
    static getFileSize(filePath: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): number;
    static getImageFileResolution(filePath: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): Promise<gm.Dimensions>;
    static resizeImage(src: string, dest: string, mode: CkValue.IMAGE_RESIZE_MODE, opt: CkType.IImageResizeOption, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): Promise<string>;
}
export default CkFileUtils;
